@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-col.c
  * Copyright 1999, 2000, 2001, Ximian, Inc.
  *
@@ -29,31 +29,34 @@
 
 #define PARENT_TYPE (gtk_object_get_type ())
 
-static GtkObjectClass *parent_class;
+static GObjectClass *parent_class;
 
 
 enum {
 	ARG_0,
-	ARG_SORTABLE,
-	ARG_COMPARE_COL
+	ARG_SORTABLE
 };
 
 static void
-etc_destroy (GtkObject *object)
+etc_finalize (GObject *object)
 {
 	ETableCol *etc = E_TABLE_COL (object);
 
-	gtk_object_unref (GTK_OBJECT(etc->ecell));
+	if (etc->ecell)
+		gtk_object_unref (GTK_OBJECT(etc->ecell));
+	etc->ecell = NULL;
 
 	if (etc->pixbuf)
 		gdk_pixbuf_unref (etc->pixbuf);
+	etc->pixbuf = NULL;
+
 	if (etc->text)
 		g_free (etc->text);
+	etc->text = NULL;
 	
-	(*parent_class->destroy)(object);
+	parent_class->finalize (object);
 }
  
-
 static void
 etc_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 {
@@ -63,9 +66,6 @@ etc_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 	case ARG_SORTABLE:
 		etc->sortable = GTK_VALUE_BOOL(*arg);
 		break;
-	case ARG_COMPARE_COL:
-		etc->compare_col = GTK_VALUE_INT(*arg);
-		break;
 	}
 }
 
@@ -78,9 +78,6 @@ etc_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 	case ARG_SORTABLE:
 		GTK_VALUE_BOOL(*arg) = etc->sortable;
 		break;
-	case ARG_COMPARE_COL:
-		GTK_VALUE_INT(*arg) = etc->compare_col;
-		break;
 	default:
 		arg->type = GTK_TYPE_INVALID;
 		break;
@@ -91,14 +88,13 @@ static void
 e_table_col_class_init (GtkObjectClass *object_class)
 {
 	parent_class = gtk_type_class (PARENT_TYPE);
-	object_class->destroy = etc_destroy;
 	object_class->get_arg = etc_get_arg;
 	object_class->set_arg = etc_set_arg;
 
+	G_OBJECT_CLASS (object_class)->finalize = etc_finalize;
+
 	gtk_object_add_arg_type ("ETableCol::sortable",
 				 GTK_TYPE_BOOL, GTK_ARG_READWRITE, ARG_SORTABLE);  
-	gtk_object_add_arg_type ("ETableCol::compare_col",
-				 GTK_TYPE_INT, GTK_ARG_READWRITE, ARG_COMPARE_COL);
 }
 
 static void
@@ -157,7 +153,6 @@ e_table_col_new (int col_idx, const char *text, double expansion, int min_width,
 	etc->is_pixbuf = FALSE;
 
 	etc->col_idx = col_idx;
-	etc->compare_col = col_idx;
 	etc->text = g_strdup (text);
 	etc->pixbuf = NULL;
 	etc->expansion = expansion;
@@ -218,7 +213,6 @@ e_table_col_new_with_pixbuf (int col_idx, const char *text, GdkPixbuf *pixbuf, d
 	etc->is_pixbuf = TRUE;
 
 	etc->col_idx = col_idx;
-	etc->compare_col = col_idx;
 	etc->text = g_strdup(text);
 	etc->pixbuf = pixbuf;
 	etc->expansion = expansion;
