@@ -111,7 +111,8 @@ e_table_search_destroy (GtkObject *object)
 {
 	ETableSearch *ets = (ETableSearch *) object;
 	
-	drop_timeout (ets);
+	/* FIXME: do we need to unregister the timeout? bad things
+           might happen if a timeout is still active. */
 	g_free (ets->priv->search_string);
 	g_free (ets->priv);
 	
@@ -132,8 +133,8 @@ e_table_search_class_init (GtkObjectClass *object_class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETableSearchClass, search),
-				e_marshal_BOOL__STRING_ENUM,
-				GTK_TYPE_BOOL, 2, GTK_TYPE_STRING, GTK_TYPE_ENUM);
+				e_marshal_BOOLEAN__STRING_INT,
+				GTK_TYPE_BOOL, 2, GTK_TYPE_STRING, GTK_TYPE_INT);
 
 	e_table_search_signals [SEARCH_ACCEPT] =
 		gtk_signal_new ("accept",
@@ -160,7 +161,7 @@ e_table_search_init (ETableSearch *ets)
 }
 
 
-guint
+GtkType
 e_table_search_get_type (void)
 {
 	static guint type = 0;
