@@ -31,6 +31,7 @@
 #include <stdio.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtksignal.h>
+#include <gtk/gtktypebuiltins.h>
 #include <libxml/parser.h>
 #include <libgnomecanvas/gnome-canvas.h>
 #include "gal/util/e-util.h"
@@ -94,7 +95,7 @@ enum {
 	ARG_DRAW_BACKGROUND,
 	ARG_DRAW_BUTTON,
 	ARG_EMULATE_LABEL_RESIZE,
-	ARG_CURSOR_POS,
+	ARG_CURSOR_POS
 };
 
 typedef struct _EEntryPrivate EEntryPrivate;
@@ -474,6 +475,11 @@ e_entry_show_popup (EEntry *entry, gboolean visible)
 	if (pop == NULL)
 		return;
 
+	/* The async query can give us a result after the focus was lost by the
+	   widget.  In that case, we don't want to show the pop-up.   */
+	if (! GTK_WIDGET_HAS_FOCUS (entry->canvas))
+		return;
+
 	if (visible) {
 		GtkAllocation *dim = &(GTK_WIDGET (entry)->allocation);
 		gint x, y, xo, yo, fudge;
@@ -1346,4 +1352,4 @@ e_entry_class_init (GtkObjectClass *object_class)
 				 GTK_TYPE_INT, GTK_ARG_READWRITE, ARG_CURSOR_POS);
 }
 
-E_MAKE_TYPE(e_entry, "EEntry", EEntry, e_entry_class_init, e_entry_init, PARENT_TYPE);
+E_MAKE_TYPE(e_entry, "EEntry", EEntry, e_entry_class_init, e_entry_init, PARENT_TYPE)
