@@ -78,7 +78,7 @@
 
 static void e_icon_bar_class_init (EIconBarClass *class);
 static void e_icon_bar_init (EIconBar *icon_bar);
-static void e_icon_bar_dispose (GObject *object);
+static void e_icon_bar_destroy (GtkObject *object);
 static void e_icon_bar_size_allocate (GtkWidget *widget,
 				      GtkAllocation *allocation);
 static gint e_icon_bar_leave_notify_event (GtkWidget *widget,
@@ -143,50 +143,70 @@ enum
 
 static guint e_icon_bar_signals[LAST_SIGNAL] = {0};
 
-#define PARENT_TYPE E_CANVAS_TYPE
 static ECanvasClass *parent_class;
 
-E_MAKE_TYPE (e_icon_bar,
-	     "EIconBar",
-	     EIconBar,
-	     e_icon_bar_class_init,
-	     e_icon_bar_init,
-	     PARENT_TYPE)
+
+GtkType
+e_icon_bar_get_type (void)
+{
+	static GtkType e_icon_bar_type = 0;
+
+	if (!e_icon_bar_type){
+		GtkTypeInfo e_icon_bar_info = {
+			"EIconBar",
+			sizeof (EIconBar),
+			sizeof (EIconBarClass),
+			(GtkClassInitFunc) e_icon_bar_class_init,
+			(GtkObjectInitFunc) e_icon_bar_init,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		parent_class = gtk_type_class (e_canvas_get_type ());
+		e_icon_bar_type = gtk_type_unique (e_canvas_get_type (),
+						   &e_icon_bar_info);
+	}
+
+	return e_icon_bar_type;
+}
+
 
 static void
 e_icon_bar_class_init (EIconBarClass *class)
 {
-	GObjectClass *object_class;
+	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	ECanvasClass *ecanvas_class;
 
-	object_class = (GObjectClass *) class;
+	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 	ecanvas_class = E_CANVAS_CLASS( class );
 
-	parent_class = g_type_class_ref (PARENT_TYPE);
-
 	e_icon_bar_signals[ITEM_SELECTED] =
-		g_signal_new ("item_selected",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-			      G_STRUCT_OFFSET (EIconBarClass, selected_item),
-			      NULL, NULL,
-			      e_marshal_NONE__BOXED_INT,
-			      G_TYPE_NONE, 2, GDK_TYPE_EVENT,
-			      G_TYPE_INT);
+		gtk_signal_new ("item_selected",
+				GTK_RUN_LAST | GTK_RUN_ACTION,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (EIconBarClass,
+						   selected_item),
+				e_marshal_NONE__BOXED_INT,
+				GTK_TYPE_NONE, 2, GDK_TYPE_EVENT,
+				GTK_TYPE_INT);
 	e_icon_bar_signals[ITEM_DRAGGED] =
-		g_signal_new ("item_dragged",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-			      G_STRUCT_OFFSET (EIconBarClass, dragged_item),
-			      NULL, NULL,
-			      e_marshal_NONE__BOXED_INT,
-			      G_TYPE_NONE, 2, GDK_TYPE_EVENT,
-			      G_TYPE_INT);
+		gtk_signal_new ("item_dragged",
+				GTK_RUN_LAST | GTK_RUN_ACTION,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (EIconBarClass,
+						   dragged_item),
+				e_marshal_NONE__BOXED_INT,
+				GTK_TYPE_NONE, 2, GDK_TYPE_EVENT,
+				GTK_TYPE_INT);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_icon_bar_signals,
+				      LAST_SIGNAL);
 
 	/* Method override */
-	object_class->dispose		 = e_icon_bar_dispose;
+	object_class->destroy		 = e_icon_bar_destroy;
 
  	widget_class->size_allocate	 = e_icon_bar_size_allocate;
  	widget_class->leave_notify_event = e_icon_bar_leave_notify_event;
@@ -270,14 +290,14 @@ e_icon_bar_new (void)
 {
 	GtkWidget *icon_bar;
 
-	icon_bar = GTK_WIDGET (g_object_new (E_ICON_BAR_TYPE, NULL));
+	icon_bar = GTK_WIDGET (gtk_type_new (e_icon_bar_get_type ()));
 
 	return icon_bar;
 }
 
 
 static void
-e_icon_bar_dispose (GObject *object)
+e_icon_bar_destroy (GtkObject *object)
 {
 	EIconBar *icon_bar;
 	int item_num;
@@ -302,7 +322,7 @@ e_icon_bar_dispose (GObject *object)
 		icon_bar->auto_scroll_timeout_id = 0;
 	}
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
 
@@ -310,7 +330,7 @@ static void
 e_icon_bar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
 	EIconBar *icon_bar;
-	gint canvas_width, canvas_height, height, val;
+	gint canvas_width, canvas_height, height;
 
 	icon_bar = E_ICON_BAR (widget);
 
@@ -323,22 +343,17 @@ e_icon_bar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	   the canvas, and reset the button labels, so they fit. */
 	e_icon_bar_recalc_common_positions (icon_bar);
 	height = e_icon_bar_recalc_item_positions (icon_bar);
-	val = GTK_LAYOUT (widget)->vadjustment->value;
 
 	gnome_canvas_set_scroll_region (GNOME_CANVAS (widget),
 					0, 0, canvas_width,
 					MAX (height, canvas_height - 1));
 
-	GTK_LAYOUT (widget)->vadjustment->value = val;
 	/* If we are editing an item, make sure it is visible. */
 	e_icon_bar_ensure_edited_item_visible (icon_bar);
 
 	GTK_LAYOUT (widget)->vadjustment->step_increment = 16;
 	if (icon_bar->vadjustment_value_changed_id == 0)
-		icon_bar->vadjustment_value_changed_id = g_signal_connect (GTK_LAYOUT (widget)->vadjustment,
-									   "value_changed",
-									   G_CALLBACK (e_icon_bar_vadjustment_value_changed),
-									   icon_bar);
+		icon_bar->vadjustment_value_changed_id = gtk_signal_connect (GTK_OBJECT (GTK_LAYOUT (widget)->vadjustment), "value_changed", GTK_SIGNAL_FUNC (e_icon_bar_vadjustment_value_changed), icon_bar);
 
 	e_icon_bar_update_highlight (icon_bar);
 }
@@ -386,16 +401,8 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 	GtkJustification justify;
 	GtkAnchorType anchor;
 	gint max_lines;
+	GdkFont *font;
 	gboolean line_wrap;
-	PangoContext *context = gtk_widget_get_pango_context (GTK_WIDGET (icon_bar));
-	PangoFontMetrics *metrics;
-
-	metrics = pango_context_get_metrics (context, gtk_widget_get_style (GTK_WIDGET (icon_bar))->font_desc, pango_context_get_language (context));
-
-	text_h = PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)
-			       + pango_font_metrics_get_descent (metrics));
-
-	pango_font_metrics_unref (metrics);
 
 	if (icon_bar->view_type == E_ICON_BAR_LARGE_ICONS) {
 		justify = GTK_JUSTIFY_CENTER;
@@ -403,11 +410,15 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 		max_lines = 2;
 		text_x = icon_bar->text_x + (icon_bar->text_w / 2);
 		line_wrap = TRUE;
+		font = gtk_style_get_font (GTK_WIDGET (icon_bar)->style);
+		text_h = font->ascent + font->descent;
 	} else {
 		justify = GTK_JUSTIFY_LEFT;
 		anchor = GTK_ANCHOR_NW;
 		max_lines = 1;
 		text_x = icon_bar->text_x;
+		font = gtk_style_get_font (GTK_WIDGET (icon_bar)->style);
+		text_h = font->ascent + font->descent;
 		line_wrap = FALSE;
 	}
 
@@ -463,6 +474,7 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 	return y;
 }
 
+
 static gint
 e_icon_bar_leave_notify_event (GtkWidget *widget, GdkEventCrossing *event)
 {
@@ -581,12 +593,13 @@ e_icon_bar_style_set (GtkWidget *widget, GtkStyle *previous_style) {
 				       EIconBarItem, item_num);
 
 		flattened = flatten_alpha (item->pixbuf,
-					   rgb_from_gdk_color (&style->bg [GTK_STATE_ACTIVE]));
+					   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
 
 		gnome_canvas_item_set (item->image, 				      
 				       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : item->pixbuf,
 				       NULL);
 		gnome_canvas_item_set (item->text,
+				       "font_gdk", gtk_style_get_font (style),
 				       "fill_color_gdk", &style->fg [GTK_STATE_NORMAL],
 				       NULL);
 
@@ -595,10 +608,11 @@ e_icon_bar_style_set (GtkWidget *widget, GtkStyle *previous_style) {
 			gdk_pixbuf_unref (flattened);
 
 	}
-
+	
 	e_icon_bar_recalc_item_positions (icon_bar);
 }
 
+
 /**
  * e_icon_bar_add_item:
  * @icon_bar: An #EIconBar.
@@ -619,10 +633,9 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 	GtkAnchorType anchor;
 	gint max_lines, retval;
 	GtkStyle *style;
+	GdkFont *font;
 	gdouble text_x, clip_height;
 	GdkPixbuf *flattened = NULL;
-	PangoContext *context;
-	PangoFontMetrics *metrics;
 
 	g_return_val_if_fail (E_IS_ICON_BAR (icon_bar), -1);
 	g_return_val_if_fail (text != NULL, -1);
@@ -643,16 +656,11 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 
 	gtk_widget_ensure_style (GTK_WIDGET (icon_bar));
 	style = GTK_WIDGET (icon_bar)->style;
-	
-	context = gtk_widget_get_pango_context (GTK_WIDGET (icon_bar));
-
-	metrics = pango_context_get_metrics (context, gtk_widget_get_style (GTK_WIDGET (icon_bar))->font_desc, pango_context_get_language (context));
-	clip_height = max_lines * PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)
-						+ pango_font_metrics_get_descent (metrics));
-	pango_font_metrics_unref (metrics);
-
+	font = gtk_style_get_font (style);
+	clip_height = max_lines * (font->ascent + font->descent);
 	item.text = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (icon_bar)->root),
 					   e_text_get_type (),
+					   "font_gdk", font,
 					   "fill_color_gdk", &style->fg [GTK_STATE_NORMAL],
 					   "use_ellipsis", TRUE,
 					   "anchor", anchor,
@@ -662,7 +670,6 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 					   "max_lines", max_lines,
 					   "clip", TRUE,
 					   "clip_width", (gdouble) (icon_bar->text_w),
-					   "width", (gdouble) (icon_bar->text_w),
 					   "clip_height", clip_height,
 					   "text", text,
 					   "draw_background", FALSE,
@@ -671,16 +678,16 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 	e_canvas_item_move_absolute(item.text,
 				    text_x, 0);
 
-	g_signal_connect (item.text, "event",
-			  G_CALLBACK (e_icon_bar_on_item_event),
-			  icon_bar);
+	gtk_signal_connect (GTK_OBJECT (item.text), "event",
+			    GTK_SIGNAL_FUNC (e_icon_bar_on_item_event),
+			    icon_bar);
 
 	item.pixbuf = image;
 	if (image)
-		gdk_pixbuf_ref (image);
+	gdk_pixbuf_ref (image);
 
 	flattened = flatten_alpha (image,
-				   rgb_from_gdk_color (&style->bg [GTK_STATE_ACTIVE]));
+				   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
 	
 	item.image = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (icon_bar)->root),
 					    gnome_canvas_pixbuf_get_type (),
@@ -694,9 +701,9 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 		/* the canvas item holds the reference now */
 		gdk_pixbuf_unref (flattened);
 
-	g_signal_connect (item.image, "event",
-			  G_CALLBACK (e_icon_bar_on_item_event),
-			  icon_bar);
+	gtk_signal_connect (GTK_OBJECT (item.image), "event",
+			    GTK_SIGNAL_FUNC (e_icon_bar_on_item_event),
+			    icon_bar);
 
 	item.data = NULL;
 	item.destroy = NULL;
@@ -718,6 +725,7 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 	return retval;
 }
 
+
 /**
  * e_icon_bar_reorder_item:
  * @icon_bar: An #EIconBar.
@@ -805,9 +813,9 @@ e_icon_bar_get_item_image	(EIconBar	  *icon_bar,
 	g_return_val_if_fail (item_num < icon_bar->items->len, NULL);
 
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
-	g_object_get (item->image,
-		      "GnomeCanvasPixbuf::pixbuf", &image,
-		      NULL);
+	gtk_object_get (GTK_OBJECT (item->image),
+			"GnomeCanvasPixbuf::pixbuf", &image,
+			NULL);
 	return image;
 }
 
@@ -836,7 +844,7 @@ e_icon_bar_set_item_image	(EIconBar	  *icon_bar,
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
 
 	flattened = flatten_alpha (item->pixbuf,
-				   rgb_from_gdk_color (&style->bg [GTK_STATE_ACTIVE]));
+				   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
 
 	gnome_canvas_item_set (item->image,
 			       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : image,
@@ -868,9 +876,9 @@ e_icon_bar_get_item_text	(EIconBar	  *icon_bar,
 	g_return_val_if_fail (item_num < icon_bar->items->len, NULL);
 
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
-	g_object_get (item->text,
-		      "EText::text", &text,
-		      NULL);
+	gtk_object_get (GTK_OBJECT (item->text),
+			"EText::text", &text,
+			NULL);
 
 	return text;
 }
@@ -1027,8 +1035,8 @@ e_icon_bar_on_item_event (GnomeCanvasItem *item,
 		if (icon_bar->editing_item_num == -1
 		    || icon_bar->editing_item_num != item_num) {
 			e_icon_bar_item_pressed (icon_bar, item_num, event);
-			g_signal_stop_emission_by_name (item,
-							"event");
+			gtk_signal_emit_stop_by_name (GTK_OBJECT (item),
+						      "event");
 			return TRUE;
 		}
 		break;
@@ -1042,8 +1050,8 @@ e_icon_bar_on_item_event (GnomeCanvasItem *item,
 		if (icon_bar->editing_item_num == -1
 		    || icon_bar->editing_item_num != item_num) {
 			e_icon_bar_item_released (icon_bar, item_num, event);
-			g_signal_stop_emission_by_name (item,
-							"event");
+			gtk_signal_emit_stop_by_name (GTK_OBJECT (item),
+						      "event");
 			return TRUE;
 		}
 		break;
@@ -1102,9 +1110,9 @@ e_icon_bar_item_pressed (EIconBar *icon_bar,
 				  GDK_BUTTON1_MOTION_MASK,
 				  NULL, NULL, event->button.time);
 	} else if (button == 3) {
-		g_signal_emit (icon_bar,
-			       e_icon_bar_signals[ITEM_SELECTED], 0,
-			       event, item_num);
+		gtk_signal_emit (GTK_OBJECT (icon_bar),
+				 e_icon_bar_signals[ITEM_SELECTED],
+				 event, item_num);
 	}
 }
 
@@ -1127,9 +1135,9 @@ e_icon_bar_item_released (EIconBar *icon_bar,
 
 		if (icon_bar->pressed_item_num != -1
 		    && icon_bar->pressed_item_num == icon_bar->mouse_over_item_num) {
-			g_signal_emit (icon_bar,
-				       e_icon_bar_signals[ITEM_SELECTED], 0,
-				       event, item_num);
+			gtk_signal_emit (GTK_OBJECT (icon_bar),
+					 e_icon_bar_signals[ITEM_SELECTED],
+					 event, item_num);
 		}
 
 		icon_bar->pressed_item_num = -1;
@@ -1158,9 +1166,9 @@ e_icon_bar_item_motion (EIconBar *icon_bar,
 			   a pointer grab. */
 			gdk_pointer_ungrab (event->motion.time);
 
-			g_signal_emit (icon_bar,
-				       e_icon_bar_signals[ITEM_DRAGGED], 0,
-				       event, icon_bar->dragged_item_num);
+			gtk_signal_emit (GTK_OBJECT (icon_bar),
+					 e_icon_bar_signals[ITEM_DRAGGED],
+					 event, icon_bar->dragged_item_num);
 			
 			/* Don't show the button as pressed while dragging. */
 			icon_bar->pressed_item_num = -1;
