@@ -35,14 +35,23 @@
 #ifndef __E_I18N_H__
 #define __E_I18N_H__
 
-#include <glib.h>
+#include <libgnome/gnome-i18n.h>
 
 G_BEGIN_DECLS
 
 #ifdef ENABLE_NLS
-#    include <libintl.h>
+	/* this function is defined in e-util.c */
+	extern char *e_gettext (const char *msgid);
 #    undef _
-#    define _(String) dgettext (PACKAGE, String)
+#    ifdef GNOME_EXPLICIT_TRANSLATION_DOMAIN
+#        define _(String) dgettext (GNOME_EXPLICIT_TRANSLATION_DOMAIN, String)
+/* No parentheses allowed here since that breaks string concatenation. */
+#        define E_I18N_DOMAIN GNOME_EXPLICIT_TRANSLATION_DOMAIN
+#    else
+#        define _(String) dgettext (PACKAGE, String)
+/* No parentheses allowed here since that breaks string concatenation. */
+#        define E_I18N_DOMAIN PACKAGE
+#    endif
 #    ifdef gettext_noop
 #        define N_(String) gettext_noop (String)
 #    else
@@ -57,27 +66,10 @@ G_BEGIN_DECLS
 #    define bindtextdomain(Domain,Directory) (Domain)
 #    define _(String) (String)
 #    define N_(String) (String)
+/* No parentheses allowed here since that breaks string concatenation. */
+#    define E_I18N_DOMAIN ""
 #endif
 
-/*
- * Do not remove the following define, nor do surround it with ifdefs.
- *
- * If you get any `redefined' errors, it means that you are including
- * -incorrectly- a header file provided by gnome-libs before this file.
- * To correctly solve this issue include this file before any libgnome/
- * libgnomeui headers
- */
-
-#define __GNOME_I18N_H__ 1
-
-
-/* This is copied staight out of the prototypes for gnome-i18n.h */
-const char *gnome_i18n_get_language(void);
-GList      *gnome_i18n_get_language_list (const gchar *category_name);
-void	   gnome_i18n_set_preferred_language (const char *val);
-const char *gnome_i18n_get_preferred_language (void);
-void gnome_i18n_init (void);
-
 G_END_DECLS
 
 #endif /* __E_I18N_H__ */
