@@ -24,7 +24,7 @@
 #ifndef _E_REFLOW_MODEL_H_
 #define _E_REFLOW_MODEL_H_
 
-#include <glib-object.h>
+#include <gtk/gtkobject.h>
 #include <libgnomecanvas/gnome-canvas.h>
 
 #ifdef __cplusplus
@@ -32,18 +32,17 @@ extern "C" {
 #endif /* __cplusplus */
 
 #define E_REFLOW_MODEL_TYPE        (e_reflow_model_get_type ())
-#define E_REFLOW_MODEL(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_REFLOW_MODEL_TYPE, EReflowModel))
-#define E_REFLOW_MODEL_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_REFLOW_MODEL_TYPE, EReflowModelClass))
-#define E_IS_REFLOW_MODEL(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_REFLOW_MODEL_TYPE))
-#define E_IS_REFLOW_MODEL_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_REFLOW_MODEL_TYPE))
-#define E_REFLOW_MODEL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), E_REFLOW_MODEL_TYPE, EReflowModelClass))
+#define E_REFLOW_MODEL(o)          (GTK_CHECK_CAST ((o), E_REFLOW_MODEL_TYPE, EReflowModel))
+#define E_REFLOW_MODEL_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_REFLOW_MODEL_TYPE, EReflowModelClass))
+#define E_IS_REFLOW_MODEL(o)       (GTK_CHECK_TYPE ((o), E_REFLOW_MODEL_TYPE))
+#define E_IS_REFLOW_MODEL_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_REFLOW_MODEL_TYPE))
 
 typedef struct {
-	GObject   base;
+	GtkObject   base;
 } EReflowModel;
 
 typedef struct {
-	GObjectClass parent_class;
+	GtkObjectClass parent_class;
 
 	/*
 	 * Virtual methods
@@ -70,7 +69,7 @@ typedef struct {
 	void        (*model_item_changed)  (EReflowModel *etm, int n);
 } EReflowModelClass;
 
-GType            e_reflow_model_get_type        (void);
+GtkType          e_reflow_model_get_type        (void);
 
 /**/
 void             e_reflow_model_set_width       (EReflowModel     *e_reflow_model,
